summaryrefslogtreecommitdiff
path: root/xmake/tools/dmd.lua
diff options
context:
space:
mode:
authorruki <[email protected]>2017-02-21 23:32:31 +0800
committerruki <[email protected]>2017-02-21 23:32:31 +0800
commitc3d883feee28fd29cfdde759f7a5252049bc6d1e (patch)
treec1b4e3a1768533c346d4b4a6b9ab08fa5324b5ec /xmake/tools/dmd.lua
parentfb6033c52082b69041783dc23a8d5b07f9bf007a (diff)
modify flags
Diffstat (limited to 'xmake/tools/dmd.lua')
-rwxr-xr-xxmake/tools/dmd.lua10
1 files changed, 5 insertions, 5 deletions
diff --git a/xmake/tools/dmd.lua b/xmake/tools/dmd.lua
index 8329e1a3c..e71a0f51c 100755
--- a/xmake/tools/dmd.lua
+++ b/xmake/tools/dmd.lua
@@ -38,14 +38,14 @@ function init(shellname, kind)
_g.kind = kind
-- init arflags
- _g["dd-arflags"] = { "-lib" }
+ _g.arflags = { "-lib" }
-- init shflags
- _g["dd-shflags"] = { "-shared", "-fPIC" }
+ _g.shflags = { "-shared", "-fPIC" }
- -- init dflags for the kind: shared
- _g.shared = {}
- _g.shared.dflags = {"-fPIC"}
+ -- init dcflags for the kind: shared
+ _g.shared = {}
+ _g.shared.dcflags = {"-fPIC"}
-- init features
_g.features =